@@ -19,7 +19,7 @@ import cgi
 import urllib2
 from urllib import urlencode
 from etree import etree
-from .util import openURL, testXMLValue
+from .util import openURL, testXMLValue, extract_xml_list
 from fgdc import Metadata
 from iso import MD_Metadata
 
@@ -251,7 +251,7 @@ class WebMapService(object):
 
     def getfeatureinfo(self):
         raise NotImplementedError
-    
+
     def getOperationByName(self, name): 
         """Return a named content item."""
         for item in self.operations:
@@ -268,7 +268,7 @@ class ServiceIdentification(object):
         self.version = version
         self.title = testXMLValue(self._root.find('Title'))
         self.abstract = testXMLValue(self._root.find('Abstract'))
-        self.keywords = [f.text for f in self._root.findall('KeywordList/Keyword')]
+        self.keywords = extract_xml_list(self._root.findall('KeywordList/Keyword'))
         self.accessconstraints = testXMLValue(self._root.find('AccessConstraints'))
         self.fees = testXMLValue(self._root.find('Fees'))
 
@@ -304,7 +304,7 @@ class ServiceProvider(object):
             if item.name == name:
                 return item
         raise KeyError, "No operation named %s" % name
-
+        
 class ContentMetadata:
     """
     Abstraction for WMS layer metadata.
@@ -451,6 +451,14 @@ class ContentMetadata:
                 if extent.text:
                     self.timepositions=extent.text.split(',')
                     break
+                
+        # Elevations - available vertical levels
+        self.elevations=None
+        for extent in elem.findall('Extent'):
+            if extent.attrib.get("name").lower() =='elevation':
+                if extent.text:
+                    self.elevations=extent.text.split(',')
+                    break                
 
         # MetadataURLs
         self.metadataUrls = []
